@@ -2,12 +2,18 @@
 # Copyright (c) 2019-present, Blosc Development Team <blosc@blosc.org>
 # All rights reserved.
 #
-# This source code is licensed under a BSD-style license (found in the
-# LICENSE file in the root directory of this source tree)
+# SPDX-License-Identifier: BSD-3-Clause
 #######################################################################
+
 from abc import ABC, abstractmethod
 from collections.abc import Sequence
 
+try:
+    from numpy.typing import DTypeLike
+except (ImportError, AttributeError):
+    # fallback to internal module (use with caution)
+    from numpy._typing import DTypeLike
+
 import numpy as np
 
 import blosc2
@@ -569,6 +575,20 @@ class ProxyNDField(blosc2.Operand):
         return nparr[self.field]
 
 
+def _convert_dtype(dt: str | DTypeLike):
+    """
+    Attempts to convert to blosc2.dtype (i.e. numpy dtype)
+    """
+    if hasattr(dt, "as_numpy_dtype"):
+        dt = dt.as_numpy_dtype
+    try:
+        return np.dtype(dt)
+    except TypeError:  # likely passed e.g. a torch.float64
+        return np.dtype(str(dt).split(".")[1])
+    except Exception as e:
+        raise TypeError("Could not parse dtype arg {dt}.") from e
+
+
 class SimpleProxy(blosc2.Operand):
     """
     Simple proxy for any data container to be used with the compute engine.
@@ -592,13 +612,13 @@ class SimpleProxy(blosc2.Operand):
 
     def __init__(self, src, chunks: tuple | None = None, blocks: tuple | None = None):
         if not hasattr(src, "shape") or not hasattr(src, "dtype"):
-            # If the source is not a NumPy array, convert it to one
+            # If the source is not an array, convert it to NumPy
             src = np.asarray(src)
         if not hasattr(src, "__getitem__"):
             raise TypeError("The source must have a __getitem__ method")
         self._src = src
-        self._dtype = src.dtype
-        self._shape = src.shape
+        self._dtype = _convert_dtype(src.dtype)
+        self._shape = src.shape if isinstance(src.shape, tuple) else tuple(src.shape)
         # Compute reasonable values for chunks and blocks
         cparams = blosc2.CParams(clevel=0)
 
@@ -629,6 +649,11 @@ class SimpleProxy(blosc2.Operand):
         """The data type of the source array."""
         return self._dtype
 
+    @property
+    def ndim(self):
+        """The number of dimensions of the source array."""
+        return len(self.shape)
+
     def __getitem__(self, item: slice | list[slice]) -> np.ndarray:
         """
         Get a slice as a numpy.ndarray (via this proxy).
@@ -642,7 +667,37 @@ class SimpleProxy(blosc2.Operand):
         out: numpy.ndarray
             An array with the data slice.
         """
-        return self._src[item]
+        out = self._src[item]
+        if not hasattr(out, "shape") or out.shape == ():
+            return out
+        else:
+            # avoids copy for PyTorch (JAX/Tensorflow will always copy,
+            # no easy way around it)
+            return np.asarray(out)
+
+
+def as_simpleproxy(*arrs: Sequence[blosc2.Array]) -> tuple[SimpleProxy | blosc2.Operand]:
+    """
+    Convert an Array object which fulfills Array protocol into SimpleProxy. If x is already a
+    blosc2.Operand simply returns object.
+
+    Parameters
+    ----------
+    arrs: Sequence[blosc2.Array]
+        Objects fulfilling Array protocol.
+
+    Returns
+    -------
+    out: tuple[blosc2.SimpleProxy | blosc2.Operand]
+        Objects with minimal interface for blosc2 LazyExpr computations.
+    """
+    out = ()
+    for x in arrs:
+        if isinstance(x, blosc2.Operand):
+            out += (x,)
+        else:
+            out += (SimpleProxy(x),)
+    return out[0] if len(out) == 1 else out
 
 
 def jit(func=None, *, out=None, disable=False, **kwargs):  # noqa: C901
